#
# spec file for package apache2-mod_mono
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname mod_mono
Name:           apache2-mod_mono
Version:        3.13
Release:        1.16
Summary:        Run ASP.NET Pages on Unix with Apache and Mono
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://www.mono-project.com/docs/web/mod_mono/
Source:         http://download.mono-project.com/sources/%{modname}/%{name}-%{version}.tar.gz
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  libapr-util1-devel
BuildRequires:  libtool
BuildRequires:  mono-devel
BuildRequires:  pkgconfig
Requires:       %{apache_mmn}
Requires:       apache2
# This must be manually entered according to xsp's protocol version
Requires:       xsp >= 3.0.11
Obsoletes:      mod_mono < 2.10
Provides:       mod_mono = %{version}-%{release}

%description
mod_mono is a module that interfaces Apache with Mono and allows
running ASP.NET pages on Unix and Unix-like systems. To load the module
into Apache, run the command "a2enmod mono" as root.

%prep
%setup -q -n %{modname}-%{version}

%build
%configure %{_with_remove_display} --disable-quiet-build
%make_build

%install
make install DESTDIR=%{buildroot} APXS_SYSCONFDIR="%{apache_sysconfdir}"

%files
%license COPYING
%{apache_libexecdir}/*
%config %{apache_sysconfdir}/*
%{_mandir}/man8/mod_mono.8%{?ext_man}

%changelog
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.13
  * Build system related changes
* Tue Mar  2 2021 Marguerite Su <i@marguerite.su>
- use apache-rpm-macros
* Tue May 26 2015 dgutu@suse.com
- Changed xsp dependency version because it was bogus
* Sat Jan 17 2015 mailaender@opensuse.org
- fix rpmlint warnings
- use the official tarball
* Fri Jan 16 2015 p.drouand@gmail.com
- Update to version 3.12
  + ChangeLog/News files have not been updated
- Remove pache2-mod_mono-apache24.patch; merged on upstream release
- Use download Url as source
- Cleanup specfile
* Wed Jan 30 2013 dimstar@opensuse.org
- Add apache2-mod_mono-apache24.patch: Fix build with Apache 2.4
- Add libtool BuildRequires and call to autoreconf, as above patch
  touches the build system.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Feb 22 2011 ajorgensen@novell.com
- Disable quiet build
* Tue Feb 22 2011 ajorgensen@novell.com
- Update to 2.10
  * http://www.go-mono.com/archive/2.10
* Fri Jan  7 2011 ajorgensen@novell.com
- Update to 2.8.2
  * Fix for CVE-2010-4225, bnc#660070
  * http://www.go-mono.com/archive/2.8
* Wed Nov  3 2010 ajorgensen@novell.com
- Update to 2.8
  * http://www.go-mono.com/archive/2.8
* Tue Mar 16 2010 ajorgensen@novell.com
- Update to 2.6.3
  * http://www.mono-project.com/Release_Notes_Mono_2.6.3
* Tue Jan 26 2010 ajorgensen@novell.com
- Update to 2.6
  * http://www.mono-project.com/Release_Notes_Mono_2.6
* Tue Aug 11 2009 ajorgensen@novell.com
- Update to 2.4.2
  * http://www.mono-project.com/Release_Notes_Mono_2.4.2
* Tue Mar 31 2009 ajorgensen@novell.com
- Update to 2.4
  * http://www.mono-project.com/Release_Notes_Mono_2.4
* Tue Aug 26 2008 ajorgensen@novell.com
- Update to 2.0 (preview 2)
  * Fixes bnc#374272, bnc#392235,
* Tue Apr 29 2008 wberrier@suse.de
- Fix .conf and apxs file location for redhat/fedora
* Tue Mar 25 2008 wberrier@suse.de
- Update to 1.9
  - New support for controlling the number of requests that are
  passed to the mod-mono-server process
* Mon Jan 14 2008 wberrier@suse.de
- Update to 1.2.6
  - New directives for controlling the life span of mod-mono-server
  - Startup of mod_mono backends synchronized across all the child
  apache processes (via a shared memory dashboard).
* Fri Aug 31 2007 wberrier@suse.de
- mod_mono_1.2.5_p5_final.patch: fix regression: avoid sem leak
* Fri Aug 17 2007 wberrier@suse.de
- put mod_mono.conf in /etc/apache2/conf.d instead of /etc/apache2
- mod_mono_1.2.5_p4.patch.bz2: Bugfixes found in 1.2.5
  - stabilization and performance fixes that accompany the bugs
  found in xsp 1.2.5
* Fri Aug  3 2007 wberrier@suse.de
- Update to 1.2.5
  - Error logging
  - support for ServerAlias directive
* Wed Jun  6 2007 wberrier@novell.com
- Update to 1.2.4
  - Connection cancellation fixes
  - better detection of apu at buildtime
* Wed Apr  4 2007 wberrier@novell.com
- Get building in build service for suse and fedora
  - mod_mono-check_headers_apuconfig.patch: patch to enable
  autodetection of apr-util headers on suse 10.1
* Tue Jan 23 2007 ro@suse.de
- drop requires for gnome-filesystem
* Sat Dec  2 2006 wberrier@suse.de
- Update to 1.2.1 (Fate #301111)
  - handle the new configurable umask directive
* Mon Nov 13 2006 poeml@suse.de
- add Provides: mod_mono = %%{version}-%%{release}
* Mon Nov 13 2006 poeml@suse.de
- fix build with versions < 10.1 of the distro where libapr-util1
  did not yet exist as a package (libapr* was in apache2-devel)
* Mon Nov 13 2006 poeml@suse.de
- rename to apache2-mod_mono
* Sat Oct 21 2006 wberrier@suse.de
- Update 1.1.18
  - fix for autohosting and virtual hosts
* Wed Aug 30 2006 wberrier@suse.de
- Update to 1.1.17
- Remove upstream patches
- Added support for X.509 client certificates
* Tue Aug  1 2006 wberrier@suse.de
- Added some patches to build against apache 2.2.2
- Removed xsp from build deps
- Update to 1.1.16.1
- src/mod_mono.c: when using autoapplications, pass all the options that
    don't have an explicit alias to XXGLOBAL, which is the internal name
    used for the mod-mono-server instance that will create new applications
    on demand. Using XXGLOBAL as an identifier is forbidden now.
- src/mod_mono.c: allow setting MonoDebug when using automatic
    applications. Before this fix, no mod-mono-server would be started.
    Fixes bug #78672.
* Fri Apr  7 2006 wberrier@novell.com
- Update to 1.1.13.5, minor bug fix release
  - Fix DoS (Critical fix for iFolder)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan  7 2006 wberrier@suse.de
- Get building with apache 2.2
  - use apr 1.1.x instead of apr provided with httpd
  - needed CPPFLAGS to find apr dev files
  - autoreconf fixes configure in order to find apache/apr headers
- Cleaned up deps (no gtk/x/gnome needed)
* Sat Nov 12 2005 wberrier@suse.de
- 1.1.10 tarball was updated
* Fri Nov 11 2005 wberrier@suse.de
- Update to 1.1.10, remove icu deps
* Fri Oct  7 2005 wberrier@suse.de
- Updated to 1.1.9.2
* Tue Aug  9 2005 gekker@suse.de
- Update to version 1.0.9
* Mon Feb 21 2005 clahey@suse.de
- Update to 1.0.6.
* Tue Dec 14 2004 clahey@suse.de
- New package.
